﻿namespace UltraChartPictureLabel
{
    using System;
    using System.Collections.Generic;
    using System.Data;
    using System.Drawing;
    using System.Windows.Forms;
    using Infragistics.UltraChart.Core.Primitives;
    using Infragistics.UltraChart.Shared.Events;
    using Infragistics.UltraChart.Shared.Styles;

    public partial class Form1 : Form
    {
        private List<string> names;
        private Dictionary<string, Image> images;
        public Form1()
        {
            this.InitializeComponent();
            this.Load += Form1_Load;
            this.ultraChart1.FillSceneGraph += UltraChart1_FillSceneGraph;
        }

        private void UltraChart1_FillSceneGraph(object sender, FillSceneGraphEventArgs e)
        {
            var imagePrimitives = new List<Primitive>();
            foreach(var primitive in e.SceneGraph)
            {
                //  Check if current primitive is Text
                var textPrimitive = primitive as Text;
                if(textPrimitive != null)
                {
                    var name = textPrimitive.GetTextString();

                    //  If the Text primitive string is one among the names add ChartImage
                    //  primitive under the Text primitive 
                    if(this.images.ContainsKey(name))
                    {
                        //  Get the corresponding image
                        var image = this.images[name];

                        //  Get the Text primitive bounds and calculate ChartImage bounds
                        var textRect = textPrimitive.bounds;
                        var imageRect = new Rectangle(
                            textRect.Left + textRect.Width / 2 - image.Width / 2,   // Center the image under the text
                            textRect.Top + 15,                                      // Add some padding between image and text
                            image.Width,
                            image.Height);

                        //  Create the ChartImage primitive, set its FitStyle and add it to
                        //  ChartImage primitives collection
                        var imagePrimitive = new ChartImage(image, imageRect);
                        imagePrimitive.FitStyle = ImageFitStyle.StretchedFit;
                        imagePrimitives.Add(imagePrimitive);
                    }
                }
            }

            //  Finally add all new ChartImage primitives to the SceneGraph collection
            e.SceneGraph.AddRange(imagePrimitives.ToArray());
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.GetNames();
            this.GetImages();

            var data = this.GetData();

            this.ultraChart1.ChartType = ChartType.ColumnChart;
            this.ultraChart1.DataSource = data;

            //  Move the X-axis a little further from the chart edge so you can fit
            //  the images
            this.ultraChart1.Axis.X.Extent = 100;
        }

        private void GetNames()
        {
            this.names = new List<string>();
            this.names.Add("John");
            this.names.Add("Ann");
            this.names.Add("Merry");
            this.names.Add("Peter");
        }

        private void GetImages()
        {
            this.images = new Dictionary<string, Image>();
            foreach(var name in this.names)
            {
                this.images[name] = Bitmap.FromFile(string.Format(@"../../images/{0}.png", name.ToLower()));
            }
        }

        private DataTable GetData()
        {
            var data = new DataTable();
            data.Columns.Add("Name", typeof(string));
            data.Columns.Add("Orders", typeof(int));

            var rnd = new Random();
            foreach(var name in this.names)
            {
                data.Rows.Add(new object[] { name, rnd.Next(50, 200) });
            }

            return data;
        }
    }
}
